@@ -235,7 +235,7 @@ impl Build {
             build.arg("--workspace");
         }
         for item in &self.exclude {
-            build.arg("--excude").arg(item);
+            build.arg("--exclude").arg(item);
         }
         if self.all {
             build.arg("--all");
@@ -343,7 +343,16 @@ impl Build {
                 let env_target = target.to_uppercase().replace('-', "_");
                 build.env("TARGET_CC", format!("clang-cl --target={}", target));
                 build.env("TARGET_CXX", format!("clang-cl --target={}", target));
+                build.env(
+                    format!("CC_{}", env_target.to_lowercase()),
+                    format!("clang-cl --target={}", target),
+                );
+                build.env(
+                    format!("CXX_{}", env_target.to_lowercase()),
+                    format!("clang-cl --target={}", target),
+                );
                 build.env("TARGET_AR", "llvm-lib");
+                build.env(format!("AR_{}", env_target), "llvm-lib");
                 build.env(format!("CARGO_TARGET_{}_LINKER", env_target), "lld-link");
 
                 let cl_flags = format!(
@@ -451,7 +460,7 @@ impl Build {
                 ProgressBar::with_draw_target(0, draw_target.into()).with_prefix(prefix).with_style(
                     ProgressStyle::default_bar()
                         .template("{spinner:.green} {prefix:.bold} [{elapsed}] {wide_bar:.green} {bytes}/{total_bytes} {msg}").unwrap()
-                        .progress_chars("█▇▆▅▄▃▂▁  "),
+                        .progress_chars("=> "),
                 ),
             );
             xwin::WorkItem {
@@ -487,7 +496,7 @@ impl Build {
                 .template(
                     "{spinner:.green} {prefix:.bold} [{elapsed}] {wide_bar:.green} {bytes}/{total_bytes} {msg}",
                 )?
-                .progress_chars("█▇▆▅▄▃▂▁  "),
+                .progress_chars("=> "),
         );
         manifest_pb.set_prefix("Manifest");
         manifest_pb.set_message("📥 downloading");
